@@ -17,7 +17,7 @@ def find_match_with_hmm(long,short):
             minhmd = hmd
     return minhmd
 
-def Separate_itChip(out_prefix,outfolder,f_filename,r_filename,f_ref,r_ref,start_forward,start_reverse,thresh_forward,thresh_reverse,range_check):
+def Separate_itChip(out_prefix,outfolder,f_filename,r_filename,f_ref,r_ref,start_forward,start_reverse,thresh_forward,thresh_reverse,range_check,compress):
     
     print(out_prefix+' start...')
     
@@ -112,9 +112,12 @@ def Separate_itChip(out_prefix,outfolder,f_filename,r_filename,f_ref,r_ref,start
             allindexes.append(4*i+1)
             allindexes.append(4*i+2)
             allindexes.append(4*i+3)
-
-        pd.DataFrame(f_list).iloc[allindexes].to_csv(outfolder+'/'+out_prefix+'_'+key+'_R1.fastq',header=False,index=False,sep='\t')
-        pd.DataFrame(r_list).iloc[allindexes].to_csv(outfolder+'/'+out_prefix+'_'+key+'_R2.fastq',header=False,index=False,sep='\t')
+        if compress == True:
+            pd.DataFrame(f_list).iloc[allindexes].to_csv(outfolder+'/'+out_prefix+'_'+key+'_R1.fq.gz',header=False,index=False,sep='\t',compression=gzip)
+            pd.DataFrame(r_list).iloc[allindexes].to_csv(outfolder+'/'+out_prefix+'_'+key+'_R2.fq.gz',header=False,index=False,sep='\t',compression=gzip)
+        else:
+            pd.DataFrame(f_list).iloc[allindexes].to_csv(outfolder+'/'+out_prefix+'_'+key+'_R1.fastq',header=False,index=False,sep='\t')
+            pd.DataFrame(r_list).iloc[allindexes].to_csv(outfolder+'/'+out_prefix+'_'+key+'_R2.fastq',header=False,index=False,sep='\t')
 
 
 def main():
@@ -149,6 +152,9 @@ def main():
     optional.add_argument("-rg", "--range", dest="range",
                         help="size of range that check index match. default: 2", metavar="RANGE")
 
+    optional.add_argument("-c", "--compress", dest="compress",
+                        help="Indicate if result files Should be compressed. True or False accepted.", metavar="COMPRESS")
+
     args = parser.parse_args()
     args = vars(args)
 
@@ -188,4 +194,14 @@ def main():
     else:
         range_check = 1
 
-    Separate_itChip(args['out_prefix'],args['outfolder'],args['f_filename'],args['r_filename'],f_ref,r_ref,start_forward,start_reverse,thresh_forward,thresh_reverse,range_check)
\ No newline at end of file
+    if args['compress'] == None:
+        compress = True
+    elif args['compress'] == 'True':
+        compress = True
+    elif args['compress'] == 'False':
+        compress = False
+    else:
+        print('Only True or False accepted for --compress')
+        sys.exit(1)
+
+    Separate_itChip(args['out_prefix'],args['outfolder'],args['f_filename'],args['r_filename'],f_ref,r_ref,start_forward,start_reverse,thresh_forward,thresh_reverse,range_check,compress)
\ No newline at end of file
